@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,6 +49,11 @@
 
 package com.openexchange.groupware.contexts;
 
+import java.util.Arrays;
+import java.util.HashMap;
+import java.util.HashSet;
+import java.util.Map;
+import java.util.Set;
 import com.openexchange.groupware.contexts.Context;
 
 
@@ -61,6 +66,7 @@ import com.openexchange.groupware.contexts.Context;
 public class SimContext implements Context {
     
     private int id;
+    private Map<String, Set<String>> attributes = new HashMap<String, Set<String>>();
     
     public SimContext(int id) {
         super();
@@ -107,4 +113,15 @@ public class SimContext implements Context {
         return false;
     }
 
+    public boolean isReadOnly() {
+        return false;
+    }
+
+    public Map<String, Set<String>> getAttributes() {
+        return attributes;
+    }
+    
+    public void setAttribute(String key, String value) {
+        attributes.put(key, new HashSet<String>(Arrays.asList(value)));
+    }
 }
