@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -85,7 +85,7 @@ public class LoginException extends AbstractOXException {
      */
     @Deprecated
     public LoginException(final Code code, final Object... messageArgs) {
-        this(code.code, null, messageArgs);
+        this(code.getCode(), null, messageArgs);
     }
 
     /**
@@ -98,7 +98,7 @@ public class LoginException extends AbstractOXException {
      */
     @Deprecated
     public LoginException(final Code code, final Throwable cause, final Object... messageArgs) {
-        this(code.code, cause, messageArgs);
+        this(code.getCode(), cause, messageArgs);
     }
 
     /**
@@ -199,5 +199,9 @@ public class LoginException extends AbstractOXException {
         private Code(final LoginExceptionCodes code) {
             this.code = code;
         }
+
+        public LoginExceptionCodes getCode() {
+            return code;
+        }
     }
 }
