@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,18 +49,7 @@
 
 package com.openexchange.authentication;
 
-import static com.openexchange.authentication.LoginExceptionMessages.ACCOUNT_LOCKED_MSG;
-import static com.openexchange.authentication.LoginExceptionMessages.ACCOUNT_NOT_READY_YET_MSG;
-import static com.openexchange.authentication.LoginExceptionMessages.CLASS_NOT_FOUND_MSG;
-import static com.openexchange.authentication.LoginExceptionMessages.COMMUNICATION_MSG;
-import static com.openexchange.authentication.LoginExceptionMessages.DATABASE_DOWN_MSG;
-import static com.openexchange.authentication.LoginExceptionMessages.INSTANTIATION_FAILED_MSG;
-import static com.openexchange.authentication.LoginExceptionMessages.INVALID_CREDENTIALS_MSG;
-import static com.openexchange.authentication.LoginExceptionMessages.MISSING_PROPERTY_MSG;
-import static com.openexchange.authentication.LoginExceptionMessages.PASSWORD_EXPIRED_MSG;
-import static com.openexchange.authentication.LoginExceptionMessages.UNKNOWN_MSG;
-import static com.openexchange.authentication.LoginExceptionMessages.USER_NOT_ACTIVE_MSG;
-import static com.openexchange.authentication.LoginExceptionMessages.USER_NOT_FOUND_MSG;
+import static com.openexchange.authentication.LoginExceptionMessages.*;
 import com.openexchange.authentication.exception.LoginExceptionFactory;
 import com.openexchange.exceptions.OXErrorMessage;
 import com.openexchange.groupware.AbstractOXException.Category;
@@ -72,106 +61,61 @@ import com.openexchange.groupware.AbstractOXException.Category;
  */
 public enum LoginExceptionCodes implements OXErrorMessage {
 
-    /**
-     * Account "%s" is locked.
-     */
+    /** Account "%s" is locked. */
     ACCOUNT_LOCKED(ACCOUNT_LOCKED_MSG, Category.PERMISSION, 1),
-    /**
-     * Account "%s" is not ready yet.
-     */
+    /** Account "%1$s" is currently being created. This can take a while. Please try again later. */
     ACCOUNT_NOT_READY_YET(ACCOUNT_NOT_READY_YET_MSG, Category.TRY_AGAIN, 2),
-    /**
-     * Unknown problem: "%s".
-     */
+    /** Unknown problem: "%s". */
     UNKNOWN(UNKNOWN_MSG, Category.CODE_ERROR, 3),
-    /**
-     * Login not possible at the moment. Please try again later.
-     */
+    /** Login not possible at the moment. Please try again later. */
     COMMUNICATION(COMMUNICATION_MSG, Category.SUBSYSTEM_OR_SERVICE_DOWN, 5),
-    /**
-     * Invalid credentials.
-     */
+    /** Invalid credentials. */
     INVALID_CREDENTIALS(INVALID_CREDENTIALS_MSG, Category.USER_INPUT, 6),
-    /**
-     * Instantiating the class failed.
-     * 
-     * @deprecated this can not appear anymore with OSGi services.
-     */
+    /** Instantiating the class failed. */
     @Deprecated
     INSTANTIATION_FAILED(INSTANTIATION_FAILED_MSG, Category.CODE_ERROR, 7),
-    /**
-     * Class %1$s can not be found.
-     * 
-     * @deprecated this can not appear anymore with OSGi services.
-     */
+    /** Class %1$s can not be found. */
     @Deprecated
     CLASS_NOT_FOUND(CLASS_NOT_FOUND_MSG, Category.SETUP_ERROR, 8),
-    /**
-     * Missing property %1$s.
-     */
+    /** Missing property %1$s. */
     MISSING_PROPERTY(MISSING_PROPERTY_MSG, Category.SETUP_ERROR, 9),
-    /**
-     * database down.
-     */
+    /** database down. */
     DATABASE_DOWN(DATABASE_DOWN_MSG, Category.SUBSYSTEM_OR_SERVICE_DOWN, 10),
-    /**
-     * Your password expired.
-     */
+    /** Your password expired. */
     PASSWORD_EXPIRED(PASSWORD_EXPIRED_MSG, Category.PERMISSION, 11),
-    /**
-     * User %1$s could not be found in context %2$s.
-     */
+    /** User %1$s could not be found in context %2$s. */
     USER_NOT_FOUND(USER_NOT_FOUND_MSG, Category.CODE_ERROR, 12),
-    /**
-     * User is not activated.
-     */
-    USER_NOT_ACTIVE(USER_NOT_ACTIVE_MSG, Category.PERMISSION, 13);
+    /** User is not activated. */
+    USER_NOT_ACTIVE(USER_NOT_ACTIVE_MSG, Category.PERMISSION, 13),
+    /** Client "%1$s" is not activated. */
+    CLIENT_DENIED(CLIENT_DENIED_MSG, Category.USER_CONFIGURATION, 14),
+    /** Method "%1$s" in HTTP header authorization is not supported. */
+    UNKNOWN_HTTP_AUTHORIZATION(UNKNOWN_HTTP_AUTHORIZATION_MSG, Category.TRY_AGAIN, 15),
+    /** Only used as workaround for a redirection, This is <b>no</b> real error. */
+    REDIRECT(REDIRECT_MSG, Category.INTERNAL_ERROR, 16),
+    /** No session found. */
+    NO_SESSION_FOUND(NO_SESSION_FOUND_MSG, Category.USER_INPUT, 17);
 
-    /**
-     * Message of the exception.
-     */
     final String message;
 
-    /**
-     * Category of the exception.
-     */
     final Category category;
 
-    /**
-     * Detail number of the exception.
-     */
     final int number;
 
-    /**
-     * Default constructor.
-     * 
-     * @param message message.
-     * @param category category.
-     * @param detailNumber detail number.
-     */
     private LoginExceptionCodes(final String message, final Category category, final int detailNumber) {
         this.message = message;
         this.category = category;
         number = detailNumber;
     }
 
-    /**
-     * @return the category
-     */
     public Category getCategory() {
         return category;
     }
 
-    /**
-     * @return the message
-     */
     public String getMessage() {
         return message;
     }
 
-    /**
-     * {@inheritDoc}
-     */
     public int getDetailNumber() {
         return number;
     }
