@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,6 +49,8 @@
 
 package com.openexchange.authentication;
 
+import java.util.Map;
+
 /**
  * This information can be retrieved from the login screen for authenticating a user.
  * 
@@ -66,4 +68,11 @@ public interface LoginInfo {
      */
     String getPassword();
 
+    /**
+     * Gets additional properties possibly needed for authentication.
+     * 
+     * @return The properties as a (possibly empty) unmodifiable {@link Map map}
+     */
+    Map<String, Object> getProperties();
+
 }
