@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -81,7 +81,7 @@ public class AbstractOXException extends Exception {
     /**
      * Logger.
      */
-    private static final Log LOG = LogFactory.getLog(AbstractOXException.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(AbstractOXException.class));
 
     /**
      * For serialization.
@@ -487,7 +487,7 @@ public class AbstractOXException extends Exception {
      */
     @Override
     public String toString() {
-        final StringBuilder sb = new StringBuilder(256).append(getErrorCode()).append(" Category=").append(category.code);
+        final StringBuilder sb = new StringBuilder(256).append(getErrorCode()).append(" Category=").append(category.getCode());
         sb.append(" Message=");
         String msg = null;
         if (super.getMessage() != null) {
