@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,6 +50,8 @@
 package com.openexchange.groupware.contexts;
 
 import java.io.Serializable;
+import java.util.Map;
+import java.util.Set;
 
 /**
  * The context stores all attributes that are necessary for components dealing with context specific data. This are especially which
@@ -116,8 +118,26 @@ public interface Context extends Serializable {
      */
     boolean isUpdating();
 
+    /**
+     * Contexts can be put into read only mode if the master database server is not reachable. This method indicates if currently the master
+     * is not reachable.
+     *
+     * @return <code>true</code> if the master database server is not reachable.
+     */
+    boolean isReadOnly();
+
     /**
      * @return the context specific location inside the filestore.
      */
     String getFilestoreName();
+    
+    /**
+     * Gets the user attributes as an unmodifiable map.
+     * <p>
+     * Each attribute may point to multiple values.
+     * 
+     * @return user attributes
+     */
+    Map<String, Set<String>> getAttributes();
+
 }
