@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,24 +49,38 @@
 
 package com.openexchange.i18n;
 
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
+
 /**
  * Implementation of a {@link Translator} backed with an {@link I18nService}.
- *
+ * 
  * @author <a href="mailto:marcus.klein@open-xchange.com">Marcus Klein</a>
  */
 public class I18nTranslator implements Translator {
 
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(I18nTranslator.class));
+
     private final I18nService service;
 
     /**
      * Initializes a new {@link I18nTranslator}.
+     * 
+     * @param service The i18n service
      */
-    public I18nTranslator(I18nService service) {
+    public I18nTranslator(final I18nService service) {
         super();
         this.service = service;
     }
 
-    public String translate(String toTranslate) {
+    public String translate(final String toTranslate) {
+        if (!service.hasKey(toTranslate)) {
+            if (LOG.isWarnEnabled()) {
+                LOG.warn(new StringBuilder(64).append("I18n service for locale ").append(service.getLocale()).append(
+                    " has no translation for \"").append(toTranslate).append("\".").toString());
+            }
+            return toTranslate;
+        }
         return service.getLocalized(toTranslate);
     }
 }
