@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -57,7 +57,7 @@ package com.openexchange.i18n;
 public interface Translator {
 
     Translator EMPTY = new Translator() {
-        public String translate(String toTranslate) {
+        public String translate(final String toTranslate) {
             return toTranslate;
         }
     };
