@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -70,13 +70,13 @@ public class ConditionalRegistration {
     protected ServiceRegistration registration;
     private boolean running;
     
-    protected static final Log LOG = LogFactory.getLog(ConditionalRegistration.class);
+    protected static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(ConditionalRegistration.class));
 
-    public ConditionalRegistration(BundleContext context, String serviceName, Object service, Dictionary dict) {
+    public ConditionalRegistration(final BundleContext context, final String serviceName, final Object service, final Dictionary dict) {
         this.context = context;
         this.serviceName = serviceName;
         this.service = service;
-        this.dictionary = dict;
+        dictionary = dict;
     }
     
     public void check() {
@@ -91,7 +91,7 @@ public class ConditionalRegistration {
     }
 
     private synchronized void unregister() {
-        if(this.registration != null) {
+        if(registration != null) {
             LOG.info("Unregistering "+service+" as "+serviceName+". ");
             registration.unregister();
             registration = null;
