@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,10 +50,10 @@
 package com.openexchange.server.osgiservice;
 
 import java.util.Arrays;
-import java.util.Collections;
 import java.util.HashSet;
 import java.util.Map;
 import java.util.concurrent.ConcurrentHashMap;
+import java.util.concurrent.ConcurrentMap;
 import java.util.concurrent.atomic.AtomicBoolean;
 import org.osgi.framework.Bundle;
 import org.osgi.framework.BundleActivator;
@@ -62,6 +62,7 @@ import org.osgi.framework.BundleException;
 import org.osgi.framework.ServiceReference;
 import org.osgi.util.tracker.ServiceTracker;
 import org.osgi.util.tracker.ServiceTrackerCustomizer;
+import com.openexchange.server.ServiceLookup;
 
 /**
  * {@link DeferredActivator} - Supports the deferred starting of a bundle which highly depends on other services.
@@ -74,7 +75,7 @@ import org.osgi.util.tracker.ServiceTrackerCustomizer;
  * 
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
-public abstract class DeferredActivator implements BundleActivator {
+public abstract class DeferredActivator implements BundleActivator, ServiceLookup {
 
     private final class DeferredSTC implements ServiceTrackerCustomizer {
 
@@ -88,7 +89,7 @@ public abstract class DeferredActivator implements BundleActivator {
             super();
             this.clazz = clazz;
             this.index = index;
-            this.stcServices = services;
+            stcServices = services;
         }
 
         public Object addingService(final ServiceReference reference) {
@@ -131,7 +132,7 @@ public abstract class DeferredActivator implements BundleActivator {
         }
     }
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(DeferredActivator.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(DeferredActivator.class));
 
     /**
      * An atomic boolean to keep track of started/stopped status.
@@ -161,7 +162,7 @@ public abstract class DeferredActivator implements BundleActivator {
     /**
      * The available service instances.
      */
-    private Map<Class<?>, Object> services;
+    private ConcurrentMap<Class<?>, Object> services;
 
     /**
      * Initializes a new {@link DeferredActivator}.
@@ -205,7 +206,7 @@ public abstract class DeferredActivator implements BundleActivator {
     private final void init() throws Exception {
         final Class<?>[] classes = getNeededServices();
         if (null == classes) {
-            services = Collections.emptyMap();
+            services = new ConcurrentHashMap<Class<?>, Object>(1);
             serviceTrackers = new ServiceTracker[0];
             availability = allAvailable = 0;
             startBundle();
@@ -349,7 +350,7 @@ public abstract class DeferredActivator implements BundleActivator {
         }
     }
 
-    public final void start(final BundleContext context) throws Exception {
+    public void start(final BundleContext context) throws Exception {
         try {
             this.context = context;
             init();
@@ -371,7 +372,7 @@ public abstract class DeferredActivator implements BundleActivator {
      */
     protected abstract void startBundle() throws Exception;
 
-    public final void stop(final BundleContext context) throws Exception {
+    public void stop(final BundleContext context) throws Exception {
         try {
             stopBundle();
             started.set(false);
@@ -402,7 +403,7 @@ public abstract class DeferredActivator implements BundleActivator {
      * @param clazz The service's class
      * @return The service obtained by service tracker or <code>null</code>
      */
-    protected final <S extends Object> S getService(final Class<? extends S> clazz) {
+    public final <S extends Object> S getService(final Class<? extends S> clazz) {
         if (null == services) {
             /*
              * Services not initialized
@@ -419,6 +420,41 @@ public abstract class DeferredActivator implements BundleActivator {
         return clazz.cast(service);
     }
 
+    /**
+     * Adds specified service (if absent).
+     *
+     * @param <S> Type of service's class
+     * @param clazz The service's class
+     * @param service The service to add
+     * @return <code>true</code> if service is added; otherwise <code>false</code> if not initialized or such a service already exists
+     */
+    protected final <S> boolean addService(final Class<? extends S> clazz, final S service) {
+        if (null == services || !clazz.isInstance(service)) {
+            /*
+             * Services not initialized
+             */
+            return false;
+        }
+        return (null == services.putIfAbsent(clazz, service));
+    }
+
+    /**
+     * Removes specified service.
+     *
+     * @param <S> Type of service's class
+     * @param clazz The service's class
+     * @return <code>true</code> if service is removes; otherwise <code>false</code> if not initialized or absent
+     */
+    protected final <S> boolean removeService(final Class<? extends S> clazz) {
+        if (null == services) {
+            /*
+             * Services not initialized
+             */
+            return false;
+        }
+        return (null != services.remove(clazz));
+    }
+
     /**
      * Checks if activator currently holds all needed services.
      * 
@@ -446,4 +482,12 @@ public abstract class DeferredActivator implements BundleActivator {
         }
         return true;
     }
+    
+    public <S> S getOptionalService(Class<? extends S> clazz) {
+    	ServiceReference serviceReference = context.getServiceReference(clazz.getName());
+    	if (serviceReference == null) {
+    		return null;
+    	}
+    	return (S) context.getService(serviceReference);
+    }
 }
