@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -53,13 +53,14 @@ import java.util.Iterator;
 import java.util.Map;
 import java.util.concurrent.ConcurrentHashMap;
 import com.openexchange.server.ServiceException;
+import com.openexchange.server.ServiceLookup;
 
 /**
  * {@link ServiceRegistry} - A registry for needed services
  * 
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
-public class ServiceRegistry {
+public class ServiceRegistry implements ServiceLookup {
 
     static final int DEFAULT_INITIAL_CAPACITY = 16;
 
@@ -179,4 +180,8 @@ public class ServiceRegistry {
         return sb.toString();
     }
 
+	public <S> S getOptionalService(Class<? extends S> clazz) {
+		return null;
+	}
+
 }
