@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -56,6 +56,44 @@ package com.openexchange.session;
  */
 public interface Session {
 
+    /**
+     * The parameter name for session lock. The parameter value is an instance of <code>java.uitl.concurrent.locks.Lock</code>.
+     * <p>
+     * Usage for locking session might look like:
+     * 
+     * <pre>
+     * import java.util.concurrent.locks.Lock
+     * ...
+     * final Lock lock = (Lock) session.getParameter(Session.PARAM_LOCK);
+     * if (null == lock) {
+     *  synchronized (session) {
+     *   ...
+     *  }
+     * } else {
+     *  lock.lock();
+     *  try {
+     *   ...
+     *  } finally {
+     *   lock.unlock();
+     *  }
+     * }
+     * </pre>
+     */
+    public static final String PARAM_LOCK = "com.openexchange.session.lock";
+
+    /**
+     * The parameter name for request counter currently active on session. The parameter value is an instance of
+     * <code>java.util.concurrent.atomic.AtomicInteger</code>.
+     */
+    public static final String PARAM_COUNTER = "com.openexchange.session.counter";
+
+    /**
+     * The parameter for optional alternative identifier.
+     *
+     * @type <code>java.lang.String</code>
+     */
+    public static final String PARAM_ALTERNATIVE_ID = "__session.altId".intern();
+
     /**
      * @return the context identifier.
      */
@@ -70,10 +108,11 @@ public interface Session {
 
     /**
      * Updates the local IP address.
+     * 
      * @param ip the new IP address associated with this session
      */
     public void setLocalIp(String ip);
-    
+
     /**
      * Gets the login name
      * 
@@ -172,12 +211,26 @@ public interface Session {
     /**
      * @return The HashCode distinguishing this session from others in the same store.
      */
-    public String getHash();
+    String getHash();
 
     /**
      * Updates the hash value of this session.
+     * 
      * @param hash The new hash value
      */
-    public void setHash(String hash);
+    void setHash(String hash);
 
+    /**
+     * The client is remembered through the whole session. It should identify what client uses the backend. Normally this is the web
+     * frontend but there may be other clients especially those that synchronize their data with OX. The client is a parameter passed to the
+     * backend during the login request. 
+     * @return the client identifier of the client using the backend.
+     */
+    String getClient();
+
+    /**
+     * Should only be used to update the client on a redirect request.
+     * @param client new client identifier.
+     */
+    void setClient(String client);
 }
