@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,27 +50,73 @@
 package com.openexchange.sessiond;
 
 import com.openexchange.groupware.contexts.Context;
+import com.openexchange.session.Session;
 
 /**
- * {@link AddSessionParameter}
- *
+ * {@link AddSessionParameter} - The parameter object to create a {@link Session session}.
+ * 
  * @author <a href="mailto:marcus.klein@open-xchange.com">Marcus Klein</a>
  */
 public interface AddSessionParameter {
 
+    /**
+     * Gets the full login incl. context information; e.g <code>test@foo</code>
+     * 
+     * @return The full login
+     */
     String getFullLogin();
 
+    /**
+     * Gets the password
+     * 
+     * @return The password
+     */
     String getPassword();
 
+    /**
+     * Gets the user identifier.
+     * 
+     * @return The user identifier
+     */
     int getUserId();
 
+    /**
+     * Gets the user login information.
+     * 
+     * @return The user login information
+     */
     String getUserLoginInfo();
 
+    /**
+     * Gets the context of the authenticated user.
+     * 
+     * @return The context.
+     */
     Context getContext();
-    
+
+    /**
+     * Gets the IP address of the connected client.
+     * 
+     * @return The IP address
+     */
     String getClientIP();
 
+    /**
+     * Gets the authentication identifier.
+     * 
+     * @return The authentication identifier
+     */
     String getAuthId();
-    
+
+    /**
+     * Gets the hash.
+     *
+     * @return The hash
+     */
     String getHash();
-}
\ No newline at end of file
+
+    /**
+     * @return the identifier of the client using the session.
+     */
+    String getClient();
+}
