@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -67,4 +67,14 @@ public interface SessiondMBean {
      */
     public int clearUserSessions(int userId, int contextId);
 
+    /**
+     * Clears all sessions belonging to specified context
+     * 
+     * @param contextId The context ID
+     */
+    public void clearContextSessions(int contextId);
+
+    int[] getNumberOfShortTermSessions();
+
+    int[] getNumberOfLongTermSessions();
 }
